@@ -5,10 +5,7 @@
 
 import os
 
-from baseblock import EnvIO
-from baseblock import FileIO
-from baseblock import Stopwatch
-from baseblock import BaseObject
+from baseblock import BaseObject, EnvIO, FileIO, Stopwatch
 
 
 class LoadRegressionTests(BaseObject):
